# ti-ding
Python package to notify when a process is finished in the terminal.


Installation: ``` pip install ti-ding ```

Usage: ``` notify <command> ```

## Next goals 
Add support for mac and unix commands

Add option to use different audio files

